import { CfnOIDCProvider } from "aws-cdk-lib/aws-iam";
import type { Construct } from "constructs";
import type { IGithubActionsIdentityProvider } from "./IGithubActionsIdentityProvider";
export interface GithubActionsIdentityProviderProps {
    /**
     * Pass a list of thumbprints for the GitHub Actions OIDC provider.
     *
     * @default - [d89e3bd43d5d909b47a18977aa9d5ce36cee184c]
     */
    readonly thumbprints?: string[];
}
export interface GithubActionsIdentityProviderImportProps {
    /**
     * An explicit account ID where the provider is defined.
     *
     * @default - the current stack's account
     */
    readonly account?: string;
    /**
     * An explicit partition where the provider is defined.
     *
     * @default - the current stack's partition
     */
    readonly partition?: string;
}
/**
 * This construct creates an ODIC provider to allow AWS access from Github Actions workflows. You'll need to instantiate
 * this construct once per AWS account.
 *
 * You can import a existing provider using `GithubActionsIdentityProvider.fromAccount`.
 *
 * To create a role that can be assumed by GitHub Actions workflows, use the `GithubActionsRole` construct.
 */
export declare class GithubActionsIdentityProvider extends CfnOIDCProvider implements IGithubActionsIdentityProvider {
    static readonly issuer: string;
    /**
     * Retrieve a reference to existing Github OIDC provider in your AWS account.
     * An AWS account can only have single Github OIDC provider configured into it,
     * so internally the reference is made by constructing the ARN from AWS
     * Account ID & Github issuer URL.
     */
    static fromAccount(scope: Construct, props?: GithubActionsIdentityProviderImportProps): IGithubActionsIdentityProvider;
    readonly arn: string;
    constructor(scope: Construct, id: string, props?: GithubActionsIdentityProviderProps);
}
